import { School } from "@/types/school";

interface SearchParams {
  query: string;
  filters: {
    location: string;
    type: string;
    level: string;
    rating: number;
  };
  page: number;
}

const ITEMS_PER_PAGE = 20;
const TOTAL_SCHOOLS = 1000;
const TOTAL_PAGES = Math.ceil(TOTAL_SCHOOLS / ITEMS_PER_PAGE);

const SCHOOL_TYPES = [
  "Public University",
  "Private University",
  "Liberal Arts College",
  "Technical Institute",
  "Research University"
];

const LOCATIONS = [
  "New York, USA",
  "London, UK",
  "Toronto, Canada",
  "Sydney, Australia",
  "Berlin, Germany",
  "Paris, France",
  "Tokyo, Japan",
  "Singapore",
  "Hong Kong",
  "Amsterdam, Netherlands"
];

const PROGRAMS = [
  "Computer Science",
  "Business Administration",
  "Engineering",
  "Medicine",
  "Law",
  "Arts and Humanities",
  "Data Science",
  "Architecture",
  "Environmental Science",
  "Psychology"
];

export async function searchSchools({ 
  query, 
  filters, 
  page 
}: SearchParams): Promise<{ 
  schools: School[];
  hasNextPage: boolean;
  nextPage: number;
}> {
  // Simulate API delay
  await new Promise((resolve) => setTimeout(resolve, 1000));

  // Generate deterministic but diverse mock data
  const schools: School[] = Array.from({ length: ITEMS_PER_PAGE }, (_, i) => {
    const globalIndex = (page - 1) * ITEMS_PER_PAGE + i;
    const schoolType = SCHOOL_TYPES[globalIndex % SCHOOL_TYPES.length];
    const location = LOCATIONS[globalIndex % LOCATIONS.length];
    
    // Generate a rating that varies but stays within a realistic range
    const baseRating = 3.5;
    const ratingVariation = (Math.sin(globalIndex) + 1) * 0.75;
    const rating = baseRating + ratingVariation;

    // Select 2-4 programs randomly but deterministically
    const programCount = 2 + (globalIndex % 3);
    const programsStart = globalIndex % (PROGRAMS.length - programCount);
    const programs = PROGRAMS.slice(programsStart, programsStart + programCount);

    return {
      id: `school-${globalIndex}`,
      name: query 
        ? `University of ${query} ${globalIndex + 1}`
        : `${schoolType} of ${location.split(',')[0]} ${globalIndex + 1}`,
      location,
      rating: Math.min(5, Math.max(3.5, rating)),
      studentCount: 5000 + (globalIndex % 45000),
      acceptanceRate: `${20 + (globalIndex % 60)}%`,
      programs,
      logo: `https://images.unsplash.com/photo-${1562774053 + (globalIndex % 10)}-701939374585?w=800&q=80`,
      website: "#",
      type: filters.type || schoolType,
      level: filters.level || "undergraduate",
    };
  });

  // Apply filters
  let filteredSchools = schools;
  
  if (filters.location) {
    filteredSchools = filteredSchools.filter(school => 
      school.location.toLowerCase().includes(filters.location.toLowerCase())
    );
  }

  if (filters.type !== "all") {
    filteredSchools = filteredSchools.filter(school => 
      school.type.toLowerCase() === filters.type.toLowerCase()
    );
  }

  if (filters.level !== "all") {
    filteredSchools = filteredSchools.filter(school => 
      school.level.toLowerCase() === filters.level.toLowerCase()
    );
  }

  if (filters.rating > 0) {
    filteredSchools = filteredSchools.filter(school => 
      school.rating >= filters.rating
    );
  }

  return {
    schools: filteredSchools,
    hasNextPage: page < TOTAL_PAGES,
    nextPage: page + 1,
  };
}

export async function getSuggestions(query: string): Promise<string[]> {
  // Simulate API delay
  await new Promise((resolve) => setTimeout(resolve, 300));

  // Generate diverse suggestions based on the query
  const suggestions = [
    `${query} University`,
    `${query} College`,
    `${query} Institute of Technology`,
    `${query} School of Business`,
    `${query} Medical School`,
    `${query} Law School`,
    `${query} State University`,
    `International ${query} University`,
    `${query} Liberal Arts College`,
    `${query} Technical Institute`,
  ];

  return suggestions.filter(s => s.toLowerCase().includes(query.toLowerCase()));
}